@@ -2,27 +2,12 @@
 # -*- coding: utf-8 -*-
 
 # insert the package for universal imports.
-import os, sys, pathlib
-
-# functions.
-def __get_file_path_base__(path, back=1):
-	path = path.replace('//','/')
-	if path[len(path)-1] == "/": path = path[:-1]
-	string, items, c = "", path.split("/"), 0
-	for item in items:
-		if c == len(items)-(1+back):
-			string += "/"+item
-			break
-		else:
-			string += "/"+item
-		c += 1
-	return string+"/"
+import os, sys, syst3m
 
 # settings.
-SOURCE_NAME = "ssht00ls"
-VERSION = "v1"
-SOURCE_PATH = __get_file_path_base__(__file__, back=2)
-BASE = __get_file_path_base__(SOURCE_PATH)
+SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=2)
+BASE = syst3m.defaults.get_source_path(SOURCE_PATH)
+OS = syst3m.defaults.check_operating_system(supported=["linux", "osx"])
 sys.path.insert(1, BASE)
 
 # imports.
@@ -83,7 +68,7 @@ class CLI(cl1.CLI):
 
 		# generate-keys.
 		elif self.argument_present('--generate-keys'):
-			encryption = self.get_encryption()
+			encryption = self.get_encryption(check_passphrase=True)
 			response = encryption.generate_keys()
 			r3sponse.log(response=response)
 
@@ -93,7 +78,7 @@ class CLI(cl1.CLI):
 			print("Selected an invalid mode.")
 
 		#
-	def get_encryption(self):
+	def get_encryption(self, check_passphrase=False):
 		# key.
 		public_key = self.get_argument('--public-key', required=False)
 		private_key = self.get_argument('--private-key', required=False)
@@ -106,14 +91,16 @@ class CLI(cl1.CLI):
 		if passphrase == None:
 			passphrase = self.get_argument('--passphrase', required=False)
 		if passphrase == None:
-			passprase = utils.__prompt_password__("Enter the key's passphrase (leave blank to use no passphrase):")
-		if passprase in ["", "none", "null"]: passprase = None
+			passphrase = utils.__prompt_password__("Enter the key's passphrase (leave blank to use no passphrase):")
+			if check_passphrase and passphrase != utils.__prompt_password__("Enter the same passphrase:"):
+				print("Error: passphrases do not match.")
+				sys.exit(1)
+		if passphrase in ["", "none", "null"]: passphrase = None
 		# encryption.
-		encryption = AssymetricAES(
+		return AssymetricAES(
 			public_key=public_key,
 			private_key=private_key,
 			passphrase=passphrase,)
-		return encryption
 	
 # main.
 if __name__ == "__main__":
