@@ -7,7 +7,7 @@ from encrypti0n.v1.classes import utils
 
 # new imports.
 import zlib, base64, binascii, glob
-from Crypto.PublicKey import RSA
+from Crypto.PublicKey import RSA as _RSA_
 from Crypto.Cipher import PKCS1_OAEP
 
 # inc imports.
@@ -25,7 +25,7 @@ class RSA(object):
 		# the key's passphrase (Leave None for no passphrase).
 		passphrase=None,
 	):
-		self.directory = key
+		self.directory = directory
 		self.passphrase = passphrase
 		self.public_key = public_key
 		self.private_key = private_key
@@ -44,7 +44,7 @@ class RSA(object):
 			return response
 			
 		# generate.
-		key_pair = RSA.generate(4096, e=65537)
+		key_pair = _RSA_.generate(4096, e=65537)
 		public_key = key_pair.publickey()
 		public_key_pem = public_key.exportKey()
 		private_key_pem = None
@@ -80,8 +80,8 @@ class RSA(object):
 		# initialize keys.
 		if self.passphrase == None:
 			try:
-				self.public_key_object = RSA.importKey(self.public_key)
-				self.private_key_object = RSA.importKey(self.private_key)
+				self.public_key_object = _RSA_.importKey(self.public_key)
+				self.private_key_object = _RSA_.importKey(self.private_key)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -89,8 +89,8 @@ class RSA(object):
 				return response
 		else:
 			try:
-				self.public_key_object = RSA.importKey(self.public_key, passphrase=self.passphrase)
-				self.private_key_object = RSA.importKey(self.private_key, passphrase=self.passphrase)
+				self.public_key_object = _RSA_.importKey(self.public_key, passphrase=self.passphrase)
+				self.private_key_object = _RSA_.importKey(self.private_key, passphrase=self.passphrase)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -113,7 +113,7 @@ class RSA(object):
 		# initialize keys.
 		if self.passphrase == None:
 			try:
-				self.public_key_object = RSA.importKey(self.public_key)
+				self.public_key_object = _RSA_.importKey(self.public_key)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -121,7 +121,7 @@ class RSA(object):
 				return response
 		else:
 			try:
-				self.public_key_object = RSA.importKey(self.public_key, passphrase=self.passphrase)
+				self.public_key_object = _RSA_.importKey(self.public_key, passphrase=self.passphrase)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -144,7 +144,7 @@ class RSA(object):
 		# initialize keys.
 		if self.passphrase == None:
 			try:
-				self.private_key_object = RSA.importKey(self.private_key)
+				self.private_key_object = _RSA_.importKey(self.private_key)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -152,7 +152,7 @@ class RSA(object):
 				return response
 		else:
 			try:
-				self.private_key_object = RSA.importKey(self.private_key, passphrase=self.passphrase)
+				self.private_key_object = _RSA_.importKey(self.private_key, passphrase=self.passphrase)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
